{ suites, pkgs, ... }:
{
  imports = suites.lap;

  system.stateVersion = "22.11"; 

  boot.loader.efi.canTouchEfiVariables = true;
  hardware.cpu.intel.updateMicrocode = false;

  boot.initrd.availableKernelModules = [ "xhci_pci" "ahci" "usb_storage" "sd_mod" "rtsx_pci_sdmmc" ];
  boot.initrd.kernelModules = [ "dm-snapshot" ];
  boot.kernelModules = [ "kvm-intel" ];
  boot.extraModulePackages = [ ];


  fileSystems."/" =
    {
      device = "/dev/disk/by-uuid/4727151b-8c08-4d35-b9e5-36575a4f3d12";
      fsType = "btrfs";
    };

  fileSystems."/boot" =
    {
      device = "/dev/disk/by-uuid/5303-C8B9";
      fsType = "vfat";
    };

  boot.kernelParams = [ "intel_pstate=no_hwp" ];
  fileSystems."/".options = [ "noatime" "nodiratime" "discard" ];


  boot.loader.grub = {
    enable = true;
    version = 2;
    device = "nodev";
    efiSupport = true;
    enableCryptodisk = true;
    gfxmodeEfi = "1024x768";
  };
  boot.loader.efi.efiSysMountPoint = "/boot";

  boot.initrd.luks.devices = {
    root = {
      device = "/dev/disk/by-uuid/e0b1eb49-9bc5-462e-9576-52f59475aad3";
    };
  };

  hardware.opengl.extraPackages = with pkgs; [
    intel-ocl
    intel-compute-runtime
  ];

  networking.networkmanager.enable = true;
}
